me.pmatiello.mockfn.internal.mock


*call-log*clj

The atom containing the call history for the currently active mocking scope.

Is nil when called outside a mocking scope. The history may be incomplete when mocked functions are called from threads that do not inherit the current dynamic bindings, such as manually created Thread instances.

The atom containing the call history for the currently active mocking scope.

Is `nil` when called outside a mocking scope. The history may be incomplete
when mocked functions are called from threads that do not inherit the
current dynamic bindings, such as manually created `Thread` instances.
sourceraw docstring

matches-call?clj

(matches-call? expected call)

Returns whether call matches expected.

Both are call entries whose first element is a function Var and whose remaining elements are arguments. The function Var must match exactly; arguments use the mock argument-matching rules, including matchers.

Returns whether `call` matches `expected`.

Both are call entries whose first element is a function Var and whose
remaining elements are arguments. The function Var must match exactly;
arguments use the mock argument-matching rules, including matchers.
sourceraw docstring

mockclj

(mock func spec)
source

verifyclj

(verify mock)
source

cljdoc builds & hosts documentation for Clojure/Script libraries